package com.censoft.censoftrongtong.service.impl;

import java.util.List;
import java.util.stream.Collectors;

import com.censoft.censoftrongtong.domain.LedgerFloor;
import com.censoft.censoftrongtong.domain.dto.LedgerFloorDto;
import com.censoft.censoftrongtong.mapper.LedgerFloorMapper;
import com.censoft.censoftrongtong.service.ILedgerFloorService;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 基础数据-楼层Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-06-26
 */
@Service
public class LedgerFloorServiceImpl implements ILedgerFloorService
{
    @Autowired
    private LedgerFloorMapper ledgerFloorMapper;

    /**
     * 查询基础数据-楼层
     * 
     * @param id 基础数据-楼层主键
     * @return 基础数据-楼层
     */
    @Override
    public LedgerFloor selectLedgerFloorById(Long id)
    {
        return ledgerFloorMapper.selectLedgerFloorById(id);
    }

    /**
     * 查询基础数据-楼层列表
     * 
     * @param ledgerFloor 基础数据-楼层
     * @return 基础数据-楼层
     */
    @Override
    public List<LedgerFloor> selectLedgerFloorList(LedgerFloor ledgerFloor)
    {
        return ledgerFloorMapper.selectLedgerFloorList(ledgerFloor);
    }

    /**
     * 新增基础数据-楼层
     * 
     * @param ledgerFloor 基础数据-楼层
     * @return 结果
     */
    @Override
    public int insertLedgerFloor(LedgerFloor ledgerFloor)
    {
        ledgerFloor.setCreateTime(DateUtils.getNowDate());
        return ledgerFloorMapper.insertLedgerFloor(ledgerFloor);
    }

    /**
     * 修改基础数据-楼层
     * 
     * @param ledgerFloor 基础数据-楼层
     * @return 结果
     */
    @Override
    public int updateLedgerFloor(LedgerFloor ledgerFloor)
    {
        ledgerFloor.setUpdateTime(DateUtils.getNowDate());
        return ledgerFloorMapper.updateLedgerFloor(ledgerFloor);
    }

    /**
     * 批量删除基础数据-楼层
     * 
     * @param ids 需要删除的基础数据-楼层主键
     * @return 结果
     */
    @Override
    public int deleteLedgerFloorByIds(Long[] ids)
    {
        return ledgerFloorMapper.deleteLedgerFloorByIds(ids);
    }

    /**
     * 删除基础数据-楼层信息
     * 
     * @param id 基础数据-楼层主键
     * @return 结果
     */
    @Override
    public int deleteLedgerFloorById(Long id)
    {
        return ledgerFloorMapper.deleteLedgerFloorById(id);
    }

    @Override
    public List<LedgerFloorDto> getFloorListByBuildingId(Long buildingId) {
        LedgerFloor query = new LedgerFloor();
        query.setBuildingId(buildingId);
        query.setStatus("0");
        List<LedgerFloor> ledgerFloors = selectLedgerFloorList(query);
        return getLedgerFloorDtoListByLedgerFloor(ledgerFloors);
    }

    private List<LedgerFloorDto> getLedgerFloorDtoListByLedgerFloor(List<LedgerFloor> ledgerFloors) {
        return ledgerFloors.stream()
                .map(LedgerFloor::getType)
                .distinct()
                .map(type->{
                    List<LedgerFloor> children = ledgerFloors
                            .stream()
                            .filter(ledgerFloor -> type.equals(ledgerFloor.getType()))
                            .collect(Collectors.toList());
                    LedgerFloorDto ledgerFloorDto = new LedgerFloorDto();
                    ledgerFloorDto.setName(type);
                    ledgerFloorDto.setChildren(children);
                    return ledgerFloorDto;
                }).collect(Collectors.toList());
    }
}
